Imports System.IO
Imports System.Drawing.Printing

Public Class Dialogs

    'Declare variable
    Private strFileName As String
    Private objStreamToPrint As StreamReader
    Private objPrintFont As Font

    Private Sub btnOpen_Click(ByVal sender As Object, _
        ByVal e As System.EventArgs) Handles btnOpen.Click

        'Set the Open dialog properties
        With OpenFileDialog1
            .Filter = "Text files (*.txt)|*.txt|All files (*.*)|*.*"
            .FilterIndex = 1
            .Title = "Demo Open File Dialog"
        End With

        'Show the Open dialog and if the user clicks the Open button,
        'load the file
        If OpenFileDialog1.ShowDialog = Windows.Forms.DialogResult.OK Then
            Dim allText As String
            Try
                'Save the file name
                strFileName = OpenFileDialog1.FileName
                'Read the contents of the file
                allText = My.Computer.FileSystem.ReadAllText(strFileName)
                'Display the file contents in the TextBox
                txtFile.Text = allText
            Catch fileException As Exception
                Throw fileException
            End Try
        End If
    End Sub

    Private Sub btnSave_Click(ByVal sender As System.Object, _
        ByVal e As System.EventArgs) Handles btnSave.Click

        'Set the Save dialog properties
        With SaveFileDialog1
            .DefaultExt = "txt"
            .FileName = strFileName
            .Filter = "Text files (*.txt)|*.txt|All files (*.*)|*.*"
            .FilterIndex = 1
            .OverwritePrompt = True
            .Title = "Demo Save File Dialog"
        End With

        'Show the Save dialog and if the user clicks the Save button,
        'save the file
        If SaveFileDialog1.ShowDialog = Windows.Forms.DialogResult.OK Then
            Try
                'Save the file name
                strFileName = SaveFileDialog1.FileName
                Dim filePath As String
                'Open or Create the file
                filePath = System.IO.Path.Combine( _
                    My.Computer.FileSystem.SpecialDirectories.MyDocuments, _
                    strFileName)
                'Replace the contents of the file
                My.Computer.FileSystem.WriteAllText(filePath, txtFile.Text, False)
            Catch fileException As Exception
                Throw fileException
            End Try
        End If
    End Sub

    Private Sub btnFont_Click(ByVal sender As System.Object, _
        ByVal e As System.EventArgs) Handles btnFont.Click

        'Set the FontDialog control properties
        FontDialog1.ShowColor = True

        'Show the Font dialog
        If FontDialog1.ShowDialog = Windows.Forms.DialogResult.OK Then
            'If the OK button was clicked set the font
            'in the text box on the form
            txtFile.Font = FontDialog1.Font
            'Set the color of the font in the text box on the form
            txtFile.ForeColor = FontDialog1.Color
        End If
    End Sub

    Private Sub btnColor_Click(ByVal sender As System.Object, _
        ByVal e As System.EventArgs) Handles btnColor.Click

        'Show the Color dialog
        If ColorDialog1.ShowDialog = Windows.Forms.DialogResult.OK Then
            'Set the BackColor property of the form
            Me.BackColor = ColorDialog1.Color
        End If
    End Sub

    Private Sub btnPrint_Click(ByVal sender As System.Object, _
        ByVal e As System.EventArgs) Handles btnPrint.Click

        'Declare an object for the PrintDocument class
        Dim objPrintDocument As PrintDocument = New PrintDocument()

        'Set the DocumentName property
        objPrintDocument.DocumentName = "Text File Print Demo"

        'Set the PrintDialog properties
        PrintDialog1.AllowPrintToFile = False
        PrintDialog1.AllowSelection = False
        PrintDialog1.AllowSomePages = False

        'Set the Document property to the objPrintDocument object
        PrintDialog1.Document = objPrintDocument

        'Show the Print dialog
        If PrintDialog1.ShowDialog() = DialogResult.OK Then
            'If the user clicked on the OK button then set the StreamReader
            'object to the file name in the strFileName variable
            objStreamToPrint = New StreamReader(strFileName)

            'Set the print font
            objPrintFont = New Font("Arial", 10)

            'Add an event handler for the PrintPage event of the
            'objPrintDocument object
            AddHandler objPrintDocument.PrintPage, _
                AddressOf objPrintDocument_PrintPage

            'Set the PrinterSettings property of the objPrintDocument
            'object to the PrinterSettings property returned from the
            'PrintDialog control
            objPrintDocument.PrinterSettings = PrintDialog1.PrinterSettings

            'Print the text file
            objPrintDocument.Print()

            'Clean up
            objStreamToPrint.Close()
            objStreamToPrint = Nothing
        End If
    End Sub

    Private Sub objPrintDocument_PrintPage(ByVal sender As Object, _
        ByVal e As System.Drawing.Printing.PrintPageEventArgs)

        'Declare variables
        Dim sngLinesPerpage As Single = 0
        Dim sngVerticalPosition As Single = 0
        Dim intLineCount As Integer = 0
        Dim sngLeftMargin As Single = e.MarginBounds.Left
        Dim sngTopMargin As Single = e.MarginBounds.Top
        Dim strLine As String

        'Work out the number of lines per page.
        'Use the MarginBounds on the event to do this
        sngLinesPerpage = _
           e.MarginBounds.Height / objPrintFont.GetHeight(e.Graphics)

        'Now iterate through the file printing out each line.
        'This assumes that a single line is not wider than the page
        'width. Check intLineCount first so that we don't read a line
        'that we won't print
        strLine = objStreamToPrint.ReadLine()

        While (intLineCount < sngLinesPerpage And Not (strLine Is Nothing))

            'Calculate the vertical position on the page
            sngVerticalPosition = sngTopMargin + _
                (intLineCount * objPrintFont.GetHeight(e.Graphics))

            'Pass a StringFormat to DrawString for the
            'Print Preview control
            e.Graphics.DrawString(strLine, objPrintFont, Brushes.Black, _
                sngLeftMargin, sngVerticalPosition, New StringFormat())

            'Increment the line count
            intLineCount = intLineCount + 1

            'If the line count is less than the lines per page then
            'read another line of text
            If (intLineCount < sngLinesPerpage) Then
                strLine = objStreamToPrint.ReadLine()
            End If

        End While

        'If we have more lines then print another page
        If (strLine <> Nothing) Then
            e.HasMorePages = True
        Else
            e.HasMorePages = False
        End If
    End Sub

    Private Sub btnBrowse_Click(ByVal sender As System.Object, _
        ByVal e As System.EventArgs) Handles btnBrowse.Click

        'Set the FolderBrowserDialog control properties
        FolderBrowserDialog1.Description = "Select a folder for your backups:"
        FolderBrowserDialog1.RootFolder = Environment.SpecialFolder.MyComputer
        FolderBrowserDialog1.ShowNewFolderButton = False

        'Show the Browse For Folder dialog
        If FolderBrowserDialog1.ShowDialog = Windows.Forms.DialogResult.OK Then
            'Display the selected folder
            txtFile.Text = FolderBrowserDialog1.SelectedPath
        End If
    End Sub
End Class
